@@ -169,7 +169,10 @@ public:
 		modeWrite,
 		modeCache,
 		modeInfo,
-		modeFeed
+		modeFeed,
+
+		modeAppend,	// app specific placeholders...
+		modeCreate
 	};
 
 	typedef enum Mode Mode;
