@@ -256,6 +256,7 @@ unsigned AudioStream::getMono(Linear buffer, unsigned frames)
 {
 	unsigned char *iobuf = (unsigned char *)buffer;
 	unsigned count, offset, copied = 0;
+	ssize_t len;
 	Linear dbuf = NULL;
 
 	if(!isStreamable())
@@ -275,7 +276,8 @@ unsigned AudioStream::getMono(Linear buffer, unsigned frames)
 
 	while(frames--)
 	{
-		if(getBuffer(iobuf, info.framesize) < (signed)info.framesize)
+		len = getBuffer(iobuf);	// packet read
+		if(len < (ssize_t)info.framesize)
 			break;
 		++copied;
 		if(codec)
@@ -313,6 +315,7 @@ unsigned AudioStream::getStereo(Linear buffer, unsigned frames)
 {
 	unsigned char *iobuf = (unsigned char *)buffer;
 	unsigned count, offset, copied = 0;
+	ssize_t len;
 
 	if(!isStreamable())
 		return 0;
@@ -327,7 +330,8 @@ unsigned AudioStream::getStereo(Linear buffer, unsigned frames)
 
 	while(frames--)
 	{
-		if(getBuffer(iobuf, info.framesize) < (signed)info.framesize)
+		len = getBuffer(iobuf);		// packet read
+		if(len < (ssize_t)info.framesize)		
 			break;
 		++copied;
 
@@ -359,6 +363,7 @@ unsigned AudioStream::putMono(Linear buffer, unsigned frames)
 {
         Linear iobuf = buffer, dbuf = NULL;
         unsigned count, offset, copied = 0;
+	ssize_t len;
 
 	if(!isStreamable())
 		return 0;
@@ -385,14 +390,16 @@ unsigned AudioStream::putMono(Linear buffer, unsigned frames)
 		if(codec)
 		{
 			codec->encode(iobuf, framebuf, info.framecount);
-			if(putBuffer(framebuf, (signed)info.framesize) < (signed)info.framesize)
+			len = putBuffer(framebuf);
+			if(len < (ssize_t)info.framesize)
 				break;
 			++copied;
 			buffer += info.framecount;
 			continue;
 		}		
 		swapEndian(info, iobuf, info.framecount);
-		if(putBuffer((Encoded)iobuf, info.framesize) < (signed)info.framesize)
+		len = putBuffer((Encoded)iobuf);
+		if(len < (ssize_t)info.framesize)
 			break;
 		++copied;
 		buffer += info.framecount;
@@ -407,6 +414,7 @@ unsigned AudioStream::putStereo(Linear buffer, unsigned frames)
 {
         Linear iobuf = buffer, mbuf = NULL;
         unsigned count, offset, copied = 0;
+	ssize_t len;
 
 	if(!isStreamable())
 		return 0;
@@ -433,14 +441,16 @@ unsigned AudioStream::putStereo(Linear buffer, unsigned frames)
 		if(codec)
 		{
 			codec->encode(iobuf, framebuf, info.framecount);
-			if(putBuffer(framebuf, info.framesize) < (signed)info.framesize)
+			len = putBuffer(framebuf);
+			if(len < (ssize_t)info.framesize)
 				break;
 			++copied;
 			buffer += info.framecount;
 			continue;
 		}
 		swapEndian(info, iobuf, info.framecount);
-		if(putBuffer((Encoded)iobuf, info.framesize) < (signed)info.framesize)
+		len = putBuffer((Encoded)iobuf);
+		if(len < (ssize_t)info.framesize)
 			break;
 		++copied;
 	}
@@ -549,7 +559,7 @@ unsigned AudioStream::getEncoded(Encoded addr, unsigned frames)
 
 	while(frames--)
 	{
-		len = getBuffer(addr, info.framesize);
+		len = getBuffer(addr);	// packet read
 		if(len < info.framesize)
 			break;
 		addr += info.framesize;
@@ -560,15 +570,16 @@ unsigned AudioStream::getEncoded(Encoded addr, unsigned frames)
 
 unsigned AudioStream::putEncoded(Encoded addr, unsigned frames)
 {
-	unsigned count = 0, len;
+	unsigned count = 0;
+	ssize_t len;
 
 	if(isLinear(info.encoding))
 		return putMono((Linear)addr, frames);
 
 	while(frames--)
 	{
-		len = putBuffer(addr, info.framesize);
-		if(len < info.framesize)
+		len = putBuffer(addr);
+		if(len < (ssize_t)info.framesize)
 			break;
 		addr += info.framesize;
 		++count;
